.. _api_dul:

*****************
DICOM Upper Layer
*****************

The DICOM Upper Layer (DUL) service provides coordinates interaction between
the ACSE, DIMSE and transport service providers.


.. toctree::
   :maxdepth: 2
   :titlesonly:
   :includehidden:

   dul.provider
   dul.pdu_primitives
   dul.pdu
   dul.pdu_items
